@@ -34,8 +34,10 @@ if 'PYVISTA_PLOT_THEME' in os.environ:
 ID_TYPE = _get_vtk_id_type()
 
 # determine if using at least vtk 5.0.0
-if vtk_version_info.major < 5:
-    raise RuntimeError('VTK version must be 5.0 or greater.')
+if vtk_version_info.major < 5:  # pragma: no cover
+    from pyvista.core.errors import VTKVersionError
+
+    raise VTKVersionError('VTK version must be 5.0 or greater.')
 
 # catch annoying numpy/vtk future warning:
 warnings.simplefilter(action='ignore', category=FutureWarning)
@@ -82,20 +84,24 @@ else:
         # Set up data directory
         os.makedirs(USER_DATA_PATH, exist_ok=True)
     except Exception as e:
-        warnings.warn(f'Unable to create `PYVISTA_USERDATA_PATH` at "{USER_DATA_PATH}"\n'
-                      f'Error: {e}\n\n'
-                      'Override the default path by setting the environmental variable '
-                      '`PYVISTA_USERDATA_PATH` to a writable path.')
+        warnings.warn(
+            f'Unable to create `PYVISTA_USERDATA_PATH` at "{USER_DATA_PATH}"\n'
+            f'Error: {e}\n\n'
+            'Override the default path by setting the environmental variable '
+            '`PYVISTA_USERDATA_PATH` to a writable path.'
+        )
         USER_DATA_PATH = ''
 
 EXAMPLES_PATH = os.path.join(USER_DATA_PATH, 'examples')
 try:
     os.makedirs(EXAMPLES_PATH, exist_ok=True)
 except Exception as e:
-    warnings.warn(f'Unable to create `EXAMPLES_PATH` at "{EXAMPLES_PATH}"\n'
-                  f'Error: {e}\n\n'
-                  'Override the default path by setting the environmental variable '
-                  '`PYVISTA_USERDATA_PATH` to a writable path.')
+    warnings.warn(
+        f'Unable to create `EXAMPLES_PATH` at "{EXAMPLES_PATH}"\n'
+        f'Error: {e}\n\n'
+        'Override the default path by setting the environmental variable '
+        '`PYVISTA_USERDATA_PATH` to a writable path.'
+    )
     EXAMPLES_PATH = ''
 
 # Send VTK messages to the logging module:
