@@ -1,4 +1,4 @@
-"""These are private methods we keep out of plotting.py to simplfy the module."""
+"""These are private methods we keep out of plotting.py to simplify the module."""
 import warnings
 
 import numpy as np
