@@ -34,11 +34,12 @@ READERS = {
     '.img': _vtk.vtkDICOMImageReader,
     '.jpeg': _vtk.vtkJPEGReader,
     '.jpg': _vtk.vtkJPEGReader,
+    '.mha': _vtk.vtkMetaImageReader,
     '.mhd': _vtk.vtkMetaImageReader,
     '.nrrd': _vtk.vtkNrrdReader,
     '.nhdr': _vtk.vtkNrrdReader,
     '.png': _vtk.vtkPNGReader,
-    '.pnm': _vtk.vtkPNMReader, # TODO: not tested
+    '.pnm': _vtk.vtkPNMReader,  # TODO: not tested
     '.slc': _vtk.vtkSLCReader,
     '.tiff': _vtk.vtkTIFFReader,
     '.tif': _vtk.vtkTIFFReader,
@@ -46,23 +47,23 @@ READERS = {
     '.glb': _vtk.vtkGLTFReader,
     '.hdr': _vtk.vtkHDRReader,
     # Other formats:
-    '.byu': _vtk.vtkBYUReader, # TODO: not tested with this extension
+    '.byu': _vtk.vtkBYUReader,  # TODO: not tested with this extension
     '.g': _vtk.vtkBYUReader,
     # '.chemml': _vtk.vtkCMLMoleculeReader, # TODO: not tested
     # '.cml': _vtk.vtkCMLMoleculeReader, # vtkMolecule is not supported by pyvista
     # TODO: '.csv': _vtk.vtkCSVReader, # vtkTables are currently not supported
     '.facet': _vtk.lazy_vtkFacetReader,
-    '.cas': _vtk.vtkFLUENTReader, # TODO: not tested
+    '.cas': _vtk.vtkFLUENTReader,  # TODO: not tested
     # '.dat': _vtk.vtkFLUENTReader, # TODO: not working
     # '.cube': _vtk.vtkGaussianCubeReader, # Contains `atom_types` which are note supported?
-    '.res': _vtk.vtkMFIXReader, # TODO: not tested
+    '.res': _vtk.vtkMFIXReader,  # TODO: not tested
     '.foam': _vtk.vtkOpenFOAMReader,
     # '.pdb': _vtk.vtkPDBReader, # Contains `atom_types` which are note supported?
     '.p3d': _vtk.lazy_vtkPlot3DMetaReader,
     '.pts': _vtk.vtkPTSReader,
     # '.particles': _vtk.vtkParticleReader, # TODO: not tested
-    #TODO: '.pht': _vtk.vtkPhasta??????,
-    #TODO: '.vpc': _vtk.vtkVPIC?????,
+    # TODO: '.pht': _vtk.vtkPhasta??????,
+    # TODO: '.vpc': _vtk.vtkVPIC?????,
     # '.bin': _vtk.lazy_vtkMultiBlockPLOT3DReader,# TODO: non-default routine
     '.tri': _vtk.vtkMCubesReader,
     '.inp': _vtk.vtkAVSucdReader,
@@ -71,7 +72,7 @@ READERS = {
 VTK_MAJOR = _vtk.vtkVersion().GetVTKMajorVersion()
 VTK_MINOR = _vtk.vtkVersion().GetVTKMinorVersion()
 
-if (VTK_MAJOR >= 8 and VTK_MINOR >= 2):
+if VTK_MAJOR >= 8 and VTK_MINOR >= 2:
     try:
         READERS['.sgy'] = _vtk.lazy_vtkSegYReader
         READERS['.segy'] = _vtk.lazy_vtkSegYReader
@@ -79,6 +80,19 @@ if (VTK_MAJOR >= 8 and VTK_MINOR >= 2):
         pass
 
 
+if VTK_MAJOR >= 9 and VTK_MINOR >= 0:
+    try:
+        READERS['.hdf'] = _vtk.lazy_vtkHDFReader
+    except AttributeError:  # pragma: no cover
+        pass
+
+if VTK_MAJOR >= 9 and VTK_MINOR >= 1:
+    try:
+        READERS['.cgns'] = _vtk.lazy_vtkCGNSReader
+    except AttributeError:  # pragma: no cover
+        pass
+
+
 def _get_ext_force(filename, force_ext=None):
     if force_ext:
         return str(force_ext).lower()
@@ -113,7 +127,7 @@ def set_vtkwriter_mode(vtk_writer, use_binary=True):
     return vtk_writer
 
 
-def standard_reader_routine(reader, filename, attrs=None):
+def standard_reader_routine(reader, filename, attrs=None, progress_bar=False):
     """Use a given reader in the common VTK reading pipeline routine.
 
     The reader must come from the ``READERS`` mapping.
@@ -132,7 +146,12 @@ def standard_reader_routine(reader, filename, attrs=None):
         arguments passed to those calls. If you do not have any
         attributes to call, pass ``None`` as the value.
 
+    progress_bar : bool, optional
+        Optionally show a progress bar.
+
     """
+    from pyvista.core.filters import _update_alg  # avoid circular import
+
     observer = pyvista.utilities.errors.Observer()
     observer.observe(reader)
 
@@ -154,20 +173,32 @@ def standard_reader_routine(reader, filename, attrs=None):
             attr(*args)
         else:
             attr()
+
     # Perform the read
-    reader.Update()
+    if filename:
+        msg = f"Reading {os.path.basename(filename)}"
+    else:
+        msg = "Reading file"
+
+    _update_alg(
+        reader,
+        progress_bar=progress_bar,
+        message=msg,
+    )
 
     # Check reader for errors
     if observer.has_event_occurred():
-        warnings.warn(f'The VTK reader `{reader.GetClassName()}` raised an error while reading the file.\n'
-                      f'\t"{observer.get_message()}"')
+        warnings.warn(
+            f'The VTK reader `{reader.GetClassName()}` raised an error while reading the file.\n'
+            f'\t"{observer.get_message()}"'
+        )
 
     data = pyvista.wrap(reader.GetOutputDataObject(0))
     data._post_file_load_processing()
     return data
 
 
-def read_legacy(filename):
+def read_legacy(filename, progress_bar=False):
     """Use VTK's legacy reader to read a file.
 
     This uses ``vtk.vtkDataSetReader`` to read the data.
@@ -177,6 +208,9 @@ def read_legacy(filename):
     filename : str
         The string path to the file to read.
 
+    progress_bar : bool, optional
+        Optionally show a progress bar. Default ``False``.
+
     Returns
     -------
     pyvista.DataSet
@@ -210,13 +244,13 @@ def read_legacy(filename):
     reader.ReadAllTensorsOn()
 
     # Perform the read
-    output = standard_reader_routine(reader, None)
+    output = standard_reader_routine(reader, None, progress_bar=progress_bar)
     if output is None:
-        raise RuntimeError('No output when using VTKs legacy reader')
+        raise RuntimeError('No output when using VTKs legacy reader.')
     return output
 
 
-def read(filename, attrs=None, force_ext=None, file_format=None):
+def read(filename, attrs=None, force_ext=None, file_format=None, progress_bar=False):
     """Read any file type supported by ``vtk`` or ``meshio``.
 
     Automatically determines the correct reader to use then wraps the
@@ -252,6 +286,7 @@ def read(filename, attrs=None, force_ext=None, file_format=None):
     * ``'.img'``
     * ``'.jpeg'``
     * ``'.jpg'``
+    * ``'.mha'``
     * ``'.mhd'``
     * ``'.nrrd'``
     * ``'.nhdr'``
@@ -307,6 +342,10 @@ def read(filename, attrs=None, force_ext=None, file_format=None):
     file_format : str, optional
         Format of file to read with meshio.
 
+    progress_bar : bool, optional
+        Optionally show a progress bar. Default ``False``. Ignored when using
+        ``meshio``.
+
     Returns
     -------
     pyvista.DataSet
@@ -339,8 +378,7 @@ def read(filename, attrs=None, force_ext=None, file_format=None):
                 name = os.path.basename(str(each))
             else:
                 name = None
-            multi[-1, name] = read(each, attrs=attrs,
-                                   file_format=file_format)
+            multi[-1, name] = read(each, attrs=attrs, file_format=file_format)
         return multi
     filename = os.path.abspath(os.path.expanduser(str(filename)))
     if not os.path.isfile(filename):
@@ -355,26 +393,28 @@ def read(filename, attrs=None, force_ext=None, file_format=None):
     # From the extension, decide which reader to use
     if attrs is not None:
         reader = get_vtk_reader(filename, force_ext=ext)
-        return standard_reader_routine(reader, filename, attrs=attrs)
+        return standard_reader_routine(reader, filename, attrs=attrs, progress_bar=progress_bar)
     elif ext in ['.e', '.exo']:
         return read_exodus(filename)
     elif ext in ['.vtk']:
         # Attempt to use the legacy reader...
-        return read_legacy(filename)
+        return read_legacy(filename, progress_bar=progress_bar)
     else:
         # Attempt find a reader in the readers mapping
         try:
             reader = get_vtk_reader(filename, force_ext=ext)
-            return standard_reader_routine(reader, filename)
+            return standard_reader_routine(reader, filename, progress_bar=progress_bar)
         except KeyError:
             # Don't fall back to meshio if using `force_ext`, which is really
             # just intended to be used with the native PyVista readers
             if force_ext is not None:
                 from meshio._exceptions import ReadError
+
                 raise ReadError
             # Attempt read with meshio
             try:
                 from meshio._exceptions import ReadError
+
                 try:
                     return read_meshio(filename)
                 except ReadError:
@@ -386,7 +426,7 @@ def read(filename, attrs=None, force_ext=None, file_format=None):
     raise IOError("This file was not able to be automatically read by pyvista.")
 
 
-def read_texture(filename, attrs=None):
+def read_texture(filename, attrs=None, progress_bar=False):
     """Load a texture from an image file.
 
     Parameters
@@ -400,6 +440,9 @@ def read_texture(filename, attrs=None):
         arguments passed to those calls. If you do not have any
         attributes to call, pass ``None`` as the value.
 
+    progress_bar : bool, optional
+        Optionally show a progress bar.
+
     Returns
     -------
     pyvista.Texture
@@ -423,7 +466,7 @@ def read_texture(filename, attrs=None):
     try:
         # initialize the reader using the extension to find it
         reader = get_vtk_reader(filename)
-        image = standard_reader_routine(reader, filename, attrs=attrs)
+        image = standard_reader_routine(reader, filename, attrs=attrs, progress_bar=progress_bar)
         if image.n_points < 2:
             raise ValueError("Problem reading the image with VTK.")
         return pyvista.Texture(image)
@@ -431,16 +474,19 @@ def read_texture(filename, attrs=None):
         # Otherwise, use the imageio reader
         pass
     import imageio
+
     return pyvista.Texture(imageio.imread(filename))
 
 
-def read_exodus(filename,
-                animate_mode_shapes=True,
-                apply_displacements=True,
-                displacement_magnitude=1.0,
-                read_point_data=True,
-                read_cell_data=True,
-                enabled_sidesets=None):
+def read_exodus(
+    filename,
+    animate_mode_shapes=True,
+    apply_displacements=True,
+    displacement_magnitude=1.0,
+    read_point_data=True,
+    read_cell_data=True,
+    enabled_sidesets=None,
+):
     """Read an ExodusII file (``'.e'`` or ``'.exo'``).
 
     Parameters
@@ -521,7 +567,7 @@ def read_exodus(filename,
     return pyvista.wrap(reader.GetOutput())
 
 
-def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None):
+def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None, progress_bar=False):
     """Read a Plot3D grid file (e.g., grid.in) and optional q file(s).
 
     Parameters
@@ -544,6 +590,9 @@ def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None):
         arguments passed to those calls. If you do not have any
         attributes to call, pass ``None`` as the value.
 
+    progress_bar : bool, optional
+        Optionally show a progress bar.
+
     Returns
     -------
     pyvista.MultiBlock
@@ -571,14 +620,15 @@ def read_plot3d(filename, q_filenames=(), auto_detect=True, attrs=None):
         # supported in VTK9.
         if len(q_filenames) > 0:
             if len(q_filenames) > 1:
-                raise RuntimeError('Reading of multiple q files is not supported '
-                                   'with this version of VTK.')
+                raise RuntimeError(
+                    'Reading of multiple q files is not supported with this version of VTK.'
+                )
             reader.SetQFileName(q_filenames[0])
 
     attrs = {} if not attrs else attrs
     attrs['SetAutoDetectFormat'] = auto_detect
 
-    return standard_reader_routine(reader, filename=None, attrs=attrs)
+    return standard_reader_routine(reader, filename=None, attrs=attrs, progress_bar=progress_bar)
 
 
 def from_meshio(mesh):
@@ -597,9 +647,7 @@ def from_meshio(mesh):
     for c in mesh.cells:
         vtk_type = meshio_to_vtk_type[c.type]
         numnodes = vtk_type_to_numnodes[vtk_type]
-        cells.append(
-            np.hstack((np.full((len(c.data), 1), numnodes), c.data)).ravel()
-        )
+        cells.append(np.hstack((np.full((len(c.data), 1), numnodes), c.data)).ravel())
         cell_type += [vtk_type] * len(c.data)
         if not _vtk.VTK9:
             offset += [next_offset + i * (numnodes + 1) for i in range(len(c.data))]
@@ -644,10 +692,7 @@ def read_meshio(filename, file_format=None):
     try:
         import meshio
     except ImportError:  # pragma: no cover
-        raise ImportError(
-            "To use this feature install meshio with:\n\n"
-            "pip install meshio"
-        )
+        raise ImportError("To use this feature install meshio with:\n\npip install meshio")
 
     # Make sure relative paths will work
     filename = os.path.abspath(os.path.expanduser(str(filename)))
@@ -688,14 +733,11 @@ def save_meshio(filename, mesh, file_format=None, **kwargs):
     try:
         import meshio
     except ImportError:  # pragma: no cover
-        raise ImportError(
-            "To use this feature install meshio with:\n\n"
-            "pip install meshio"
-        )
+        raise ImportError("To use this feature install meshio with:\n\npip install meshio")
 
     try:  # for meshio<5.0 compatibility
         from meshio.vtk._vtk import vtk_to_meshio_type
-    except:  # pragma: no cover
+    except:  # noqa: E722 pragma: no cover
         from meshio._vtk_common import vtk_to_meshio_type
 
     # Make sure relative paths will work
@@ -711,7 +753,7 @@ def save_meshio(filename, mesh, file_format=None, **kwargs):
     vtk_cell_type = mesh.celltypes
 
     # Check that meshio supports all cell types in input mesh
-    pixel_voxel = {8, 11}       # Handle pixels and voxels
+    pixel_voxel = {8, 11}  # Handle pixels and voxels
     for cell_type in np.unique(vtk_cell_type):
         if cell_type not in vtk_to_meshio_type.keys() and cell_type not in pixel_voxel:
             raise TypeError(f"meshio does not support VTK type {cell_type}.")
@@ -720,22 +762,21 @@ def save_meshio(filename, mesh, file_format=None, **kwargs):
     cells = []
     c = 0
     for offset, cell_type in zip(vtk_offset, vtk_cell_type):
-        numnodes = vtk_cells[offset+c]
+        numnodes = vtk_cells[offset + c]
         if _vtk.VTK9:  # must offset by cell count
-            cell = vtk_cells[offset+1+c:offset+1+c+numnodes]
+            cell = vtk_cells[offset + 1 + c : offset + 1 + c + numnodes]
             c += 1
         else:
-            cell = vtk_cells[offset+1:offset+1+numnodes]
+            cell = vtk_cells[offset + 1 : offset + 1 + numnodes]
         cell = (
-            cell if cell_type not in pixel_voxel
-            else cell[[0, 1, 3, 2]] if cell_type == 8
+            cell
+            if cell_type not in pixel_voxel
+            else cell[[0, 1, 3, 2]]
+            if cell_type == 8
             else cell[[0, 1, 3, 2, 4, 5, 7, 6]]
         )
-        cell_type = cell_type if cell_type not in pixel_voxel else cell_type+1
-        cell_type = (
-            vtk_to_meshio_type[cell_type] if cell_type != 7
-            else f"polygon{numnodes}"
-        )
+        cell_type = cell_type if cell_type not in pixel_voxel else cell_type + 1
+        cell_type = vtk_to_meshio_type[cell_type] if cell_type != 7 else f"polygon{numnodes}"
 
         if len(cells) > 0 and cells[-1][0] == cell_type:
             cells[-1][1].append(cell)
@@ -765,8 +806,9 @@ def save_meshio(filename, mesh, file_format=None, **kwargs):
         point_data=point_data,
         cell_data=cell_data,
         file_format=file_format,
-        **kwargs
+        **kwargs,
     )
 
+
 def _process_filename(filename):
     return os.path.abspath(os.path.expanduser(str(filename)))
